@@ -1,4 +1,5 @@
-# -*- coding: utf-8 -*-
+#!python
+# coding=utf-8
 from pocean.cf import CFDataset
 
 
@@ -32,9 +33,7 @@ class IncompleteMultidimensionalTimeseriesProfile(CFDataset):
 
         return True
 
-    def from_dataframe(self, df, variable_attributes=None, global_attributes=None):
-        variable_attributes = variable_attributes or {}
-        global_attributes = global_attributes or {}
+    def from_dataframe(cls, df, output, **kwargs):
         raise NotImplementedError
 
     def calculated_metadata(self, df=None, geometries=True, clean_cols=True, clean_rows=True):
